pub struct NodeStatusResult {
pub served: bool,
pub node: Option<NodeIdentity>,
}Fields
served: boolTrue when this app-server is being served as a remote agent node.
node: Option<NodeIdentity>Trait Implementations
Sourceimpl Clone for NodeStatusResult
impl Clone for NodeStatusResult
Sourcefn clone(&self) -> NodeStatusResult
fn clone(&self) -> NodeStatusResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NodeStatusResult
impl Debug for NodeStatusResult
Sourceimpl<'de> Deserialize<'de> for NodeStatusResult
impl<'de> Deserialize<'de> for NodeStatusResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NodeStatusResult
Sourceimpl PartialEq for NodeStatusResult
impl PartialEq for NodeStatusResult
Sourcefn eq(&self, other: &NodeStatusResult) -> bool
fn eq(&self, other: &NodeStatusResult) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for NodeStatusResult
impl Serialize for NodeStatusResult
impl StructuralPartialEq for NodeStatusResult